@@ -8,8 +8,9 @@ from betterproto import Casing
 
 from maitai._config import config
 from maitai._maitai_client import MaitaiClient
-from maitai._types import EvaluateCallback
-from maitai_gen.chat import ChatCompletionChunk, EvaluateRequest, EvaluateResponse, EvaluationContentType
+from maitai._utils import chat_completion_chunk_to_response
+from maitai_common.utils.types import EvaluateCallback
+from maitai_gen.chat import ChatCompletionChunk, ChatCompletionParams, ChatCompletionResponse, EvaluateRequest, EvaluateResponse, EvaluationContentType
 
 
 def _get_content_type(content, partial=None):
@@ -27,7 +28,8 @@ class Evaluator(MaitaiClient):
         super().__init__()
 
     @classmethod
-    async def evaluate_async(cls, session_id, reference_id, action_type, content, content_type=None, application_id=None, application_ref_name=None, callback=None):
+    async def evaluate_async(cls, session_id, reference_id, action_type, content, content_type=None, application_id=None, application_ref_name=None, callback=None, completion_params: ChatCompletionParams = None,
+                             chat_completion_response: ChatCompletionResponse = None, chat_completion_chunk: ChatCompletionChunk = None):
         if content_type is None:
             content_type = _get_content_type(content)
         if content_type is None:
@@ -35,10 +37,17 @@ class Evaluator(MaitaiClient):
         if application_id is None and application_ref_name is None:
             raise Exception('application_id or application_ref_name must be provided')
         eval_request: EvaluateRequest = cls.create_eval_request(application_id, application_ref_name, session_id, reference_id, action_type, content_type, content)
+        if completion_params is not None:
+            eval_request.chat_completion_request = cls.create_inference_request(application_ref_name, session_id, reference_id, action_type, False, True, completion_params)
+            if chat_completion_chunk is not None:
+                chat_completion_response = chat_completion_chunk_to_response(chat_completion_chunk, content)
+            eval_request.chat_completion_response = chat_completion_response
+
         await asyncio.create_task(cls.send_evaluation_request_async(eval_request, callback))
 
     @classmethod
-    def evaluate(cls, session_id, reference_id, action_type, content, content_type=None, application_id=None, application_ref_name=None, callback=None, partial=None):
+    def evaluate(cls, session_id, reference_id, action_type, content, content_type=None, application_id=None, application_ref_name=None, callback=None, partial=None, completion_params: ChatCompletionParams = None,
+                 chat_completion_response: ChatCompletionResponse = None, chat_completion_chunk: ChatCompletionChunk = None):
         if content_type is None:
             content_type = _get_content_type(content, partial)
         if content_type is None:
@@ -46,6 +55,12 @@ class Evaluator(MaitaiClient):
         if application_id is None and application_ref_name is None:
             raise Exception('application_id or application_ref_name must be provided')
         eval_request: EvaluateRequest = cls.create_eval_request(application_id, application_ref_name, session_id, reference_id, action_type, content_type, content, partial=partial)
+        if completion_params is not None:
+            eval_request.chat_completion_request = cls.create_inference_request(application_ref_name, session_id, reference_id, action_type, False, True, completion_params)
+            if chat_completion_chunk is not None:
+                chat_completion_response = chat_completion_chunk_to_response(chat_completion_chunk, content)
+            eval_request.chat_completion_response = chat_completion_response
+
         cls.run_async(cls.send_evaluation_request_async(eval_request, callback))
 
     @classmethod
@@ -57,7 +72,7 @@ class Evaluator(MaitaiClient):
 
     @classmethod
     def create_eval_request(cls, application_id, application_ref_name, session_id, reference_id, action_type,
-                            content_type, content, partial=None, fault_description=None):
+                            content_type, content, partial=None, fault_description=None, chat_completion_response=None):
         eval_request: EvaluateRequest = EvaluateRequest()
         eval_request.evaluation_content_type = content_type
         if content_type == EvaluationContentType.TEXT:
@@ -76,6 +91,7 @@ class Evaluator(MaitaiClient):
         eval_request.action_type = action_type
         if fault_description:
             eval_request.fault_description = fault_description
+        eval_request.client_version = cls.VERSION
         return eval_request
 
     @classmethod
